@@ -683,16 +683,19 @@ class CubeQuery(object):
         if dimension:
             # FIXME: temporary flat dimension hack, not sure about impact of this to other parts of the
             # framework
-            if not dimension.is_flat or dimension.has_details:
-                logical_name = dimension.name + '.' + str(field)
+            # FIXME: the third condition is a temporary quick fix for https://github.com/Stiivi/cubes/issues/14
+            field_name = str(field)
+            if not dimension.is_flat or dimension.has_details or dimension.name != field_name:
+                logical_name = dimension.name + '.' + field_name
             else:
-                logical_name = str(field)
+                logical_name = field_name
         else:
             logical_name = field
 
         self.logger.debug("getting column %s(%s) loc: %s - %s" % (field, type(field), self.locale, locale_suffix))
 
         localized_name = logical_name + locale_suffix
+
         column = self.view.c[localized_name]
         return expression.label(logical_name, column)
 
