@@ -4,7 +4,7 @@ logger_name = "cubes"
     
 def _configure_logger():
     logger = logging.getLogger(logger_name)
-    logger.setLevel(logging.DEBUG)
+    # logger.setLevel(logging.INFO)
     formatter = logging.Formatter(fmt='%(asctime)s %(levelname)s %(message)s')
             # datefmt='%a, %d %b %Y %H:%M:%S',
     
