@@ -197,18 +197,26 @@ class Model(object):
 
         # FIXME: pythonify: allow dimension objects
     	if dimensions:
-    	    for dim_name, dim_desc in dimensions.items():
-    	        desc = dict([("name", dim_name)] + dim_desc.items())
-    	        dim = Dimension(**desc)
-                self.add_dimension(dim)
+            if isinstance(dimensions, dict):
+                for dim_name, dim_desc in dimensions.items():
+                    desc = dict([("name", dim_name)] + dim_desc.items())
+                    dim = Dimension(**desc)
+                    self.add_dimension(dim)
+            else:
+                for desc in dimensions:
+                    self.add_dimension(Dimension(**desc))
 
-    	self.cubes = {}
+        self.cubes = OrderedDict()
 
     	if cubes:
-    	    for cube_name, cube_desc in cubes.items():
-    	        desc = dict([("name", cube_name)] + cube_desc.items())
-    	        cube = Cube(model = self, **desc)
-                self.add_cube(cube)
+            if isinstance(cubes, dict):
+                for cube_name, cube_desc in cubes.items():
+                    desc = dict([("name", cube_name)] + cube_desc.items())
+                    cube = Cube(model=self, **desc)
+                    self.add_cube(cube)
+            else:
+                for desc in cubes:
+                    self.add_cube(Cube(model=self,**desc))
     	        
         self.translations = {}
         
@@ -254,7 +262,6 @@ class Model(object):
 
     def add_dimension(self, dimension):
         """Add dimension to model. Replace dimension with same name"""
-
         self._dimensions[dimension.name] = dimension
 
     def remove_dimension(self, dimension):
@@ -373,7 +380,7 @@ class Model(object):
     def localize(self, translation):
         """Return localized version of model"""
         
-        model = copy.copy(self)
+        model = copy.deepcopy(self)
         
         if type(translation) == str or type(translation) == unicode:
             translation = self.translations[translation]
@@ -650,8 +657,8 @@ class Dimension(object):
     Class is not meant to be mutable.
     """
 
-    def __init__(self, name = None, label = None, levels = None,
-                 attributes = None, hierarchy = None, description = None, **desc):
+    def __init__(self, name=None, label=None, levels=None,
+                 attributes=None, hierarchy=None, description=None, **desc):
         """Create a new dimension
         """
         self.name = name
@@ -816,6 +823,14 @@ class Dimension(object):
         """Return true if dimension has only one level"""
         return len(self.levels) == 1
 
+    def attribute_reference(self, attribute, locale=None):
+        """Return an Attribute object if it is a string, otherwise just return the object."""
+        if isinstance(attribute, basestring):
+            attr = Attribute(attribute,locale=locale)
+            return attr.full_name(dimension=self)
+        else:
+            return attribute.full_name(dimension=self)
+
     def all_attributes(self, hierarchy = None):
         if not hierarchy:
             hier = self.default_hierarchy
@@ -1079,7 +1094,7 @@ class Hierarchy(object):
         """Returns True if path is base path for the hierarchy. Base path is a path where there are
         no more levels to be added - no drill down possible."""
         
-        return len(path) == len(self._levels)
+        return path != None and len(path) == len(self._levels)
 
     def to_dict(self, **options):
         """Convert to dictionary"""
@@ -1102,7 +1117,7 @@ class Hierarchy(object):
 
 class Level(object):
     """Hierarchy level
-
+    
     Attributes:
         * name: level name
         * label: human readable label 
@@ -1197,7 +1212,7 @@ class Level(object):
                 return self.attributes[1]
             else:
                 return self.key
-                
+
     def localize(self, locale):
         util.localize_common(self,locale)
         
@@ -1240,7 +1255,7 @@ class Attribute(object):
     ASC = 'asc'
     DESC = 'desc'
     
-    def __init__(self, name, label = None, locales = None, order = None, description = None,
+    def __init__(self, name, label=None, locales=None, order=None, description=None,
                  **kwargs):
         """Create an attribute.
         
@@ -1258,7 +1273,7 @@ class Attribute(object):
         self.name = name
         self.label = label
         self.description = description
-
+        
         if order:
             self.order = order.lower()
             if self.order == 'ascending':
@@ -1300,11 +1315,12 @@ class Attribute(object):
             d["full_name"] = self.full_name(dimension)
         return d
         
-    def full_name(self, dimension, locale = None):
+    def full_name(self, dimension, locale=None):
         """Return full name of an attribute as if it was part of `dimension`. Append `locale` if
-        it is one of of attribute's locales, otherwise raise an error. If no locale is specified
-        and attribute is localized, then first locale from list of locales is used.
+        it is one of of attribute's locales, otherwise raise an error.
         """
+        # Old behaviour: If no locale is specified and attribute is localized, then first locale from
+        # list of locales is used.
 
         if locale:
             if locale in self.locales:
@@ -1312,10 +1328,7 @@ class Attribute(object):
             else:
                 locale_suffix = "." + locale
         else:
-            if self.locales:
-                locale_suffix = "." + locales[0]
-            else:
-                locale_suffix = ""
+            locale_suffix = ""
 
         return str(dimension) + "." + self.name + locale_suffix
 
