@@ -1,9 +1,11 @@
 from application_controller import *
 from cubes_controller import *
 from model_controller import *
+from search_controller import *
 
 __all__ = [
     "ApplicationController",
     "CubesController",
-    "ModelController"
+    "ModelController",
+    "SearchController"
 ]
\ No newline at end of file
